import pytest

from rtcvis import PLF


@pytest.mark.parametrize(
    "a,b,expected",
    [
        (
            PLF([(0, 0), (2, 2)]),
            PLF([(0, 0), (1, 0.5), (2, 2.5)]),
            PLF([(0, 0), (1, 1.5), (2, 4.5)]),
        ),
        (
            PLF([(0, 0), (1, 1), (1, 0), (2, 1)]),
            PLF([(0, 1), (2, 3)]),
            PLF([(0, 1), (1, 3), (1, 2), (2, 4)]),
        ),
        (
            PLF([(0, 1), (4, 5), (8, 4)]),
            PLF([(0, 2), (2, 0), (5, 1), (8, -2)]),
            PLF([(0, 3), (2, 3), (4, 5 + 2 / 3), (5, 5.75), (8, 2)]),
        ),
        (
            PLF([(0, 2), (2, 0), (5, 1), (8, -2)]),
            PLF([(0, 2), (2, 0), (5, 1), (8, -2)]),
            PLF([(0, 4), (2, 0), (5, 2), (8, -4)]),
        ),
        (
            PLF([(-1, 0), (1, 2)]),
            PLF([(-1, 0), (0, 0), (0, 1), (1, 1)]),
            PLF([(-1, 0), (0, 1), (0, 2), (1, 3)]),
        ),
        # Check that the result is simplified
        (
            PLF([(0, 0), (1, 1), (2, 0), (3, 1), (4, 0)]),
            PLF([(0, 0), (1, -1), (2, 0), (3, -1), (4, 0)]),
            PLF([(0, 0), (4, 0)]),
        ),
    ],
)
def test_plf_add_plf(a: PLF, b: PLF, expected: PLF):
    result = a + b
    assert result == expected
